/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_SelectionChangeEvent_h
#define mozilla_dom_SelectionChangeEvent_h

#include "SelectionChangeEventBinding.h"
#include "mozilla/Attributes.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingUtils.h"
#include "mozilla/dom/Event.h"
#include "mozilla/dom/SelectionChangeEventBinding.h"

struct JSContext;
namespace mozilla {
namespace dom {

class SelectionChangeEvent : public Event
{
public:
  NS_DECL_ISUPPORTS_INHERITED
  NS_DECL_CYCLE_COLLECTION_SCRIPT_HOLDER_CLASS_INHERITED(SelectionChangeEvent, Event)
protected:
  virtual ~SelectionChangeEvent();
  explicit SelectionChangeEvent(mozilla::dom::EventTarget* aOwner);

  nsString mSelectedText;
  nsRefPtr<DOMRectReadOnly> mBoundingClientRect;
  nsTArray<SelectionChangeReason> mReasons;

public:
  virtual SelectionChangeEvent* AsSelectionChangeEvent();

  virtual JSObject* WrapObject(JSContext* aCx) MOZ_OVERRIDE;

  static already_AddRefed<SelectionChangeEvent> Constructor(mozilla::dom::EventTarget* aOwner, const nsAString& aType, const SelectionChangeEventInit& aEventInit);

  static already_AddRefed<SelectionChangeEvent> Constructor(const GlobalObject& aGlobal, const nsAString& aType, const SelectionChangeEventInit& aEventInit, ErrorResult& aRv);

  void GetSelectedText(nsString& aRetVal) const;

  DOMRectReadOnly* GetBoundingClientRect() const;

  void GetReasons(nsTArray<SelectionChangeReason>& aRetVal) const;
};

} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_SelectionChangeEvent_h
